'****************************************************************************
' Developed & Written by Greg Cook --- August 31, 2000
' Version: v2000.08.31
' Email: greg_cook@bigoot.com
' Web site: http://www.bigfoot.com/~greg_cook
'
' PURPOSE:
'
' Basic requirements for a logon script. Used as a startng point for
' developing a network logon script.
'
' USAGE:
'
' Double-click it to run, or reference in user's profiles for logging onto a
' network.
'
' DISCLAIMER:
'
' This script is FREE for your use, so please use and share with others
' as you see fit.
'
' This software is provided AS IS without warranty of any kind including but
' not limited to the implied warranties of merchantability and fitness for a
' particular purpose. The publisher assumes no liability for any alleged or
' actual damages arising from the use of this program. (Some states do not
' allow the exclusion of implied warranties, so the exclusion may not apply
' to you.)
'
' If you are interested in learning about VBScript (or JavaScript) check out:
' http://msdn.microsoft.com/scripting/
'****************************************************************************


'************************************************
' Return True if the specified "Source" file is
' newer than the specified "Destination" file.
'************************************************
Function IsFileNewer(strSource, strDestination)
  On Error Resume Next

  Dim fSource, fDestination

  With fso
    If Not .FileExists(strSource) Then
       IsFileNewer = False
       Exit Function
    End If

    If .FileExists(strDestination) Then
       Set fSource = .GetFile(strSource)
       Set fDestination = .GetFile(strDestination)
       Err.Clear
       IsFileNewer = (fSource.DateLastModified > fDestination.DateLastModified)
       Err.Clear
       Set fDestination = Nothing
       Set fSource = Nothing
    Else
       IsFileNewer = True
    End If
  End With
  Err.Clear
End Function

'************************************************
' Return the current user's username
'************************************************
Function CurrentUser()
  On Error Resume Next

  Dim strUsername
  Dim intCnt

  'Wait until the username gets filled in
  Do
   strUsername = net.UserName
   intCnt = intCnt + 1
  Loop While Len(strUsername) = 0 And intCnt < 32765
  Err.Clear

  'If the username is not empty    
  If Len(strUsername) <> 0 Then CurrentUser = LCase(strUsername)
  Err.Clear
End Function

'************************************************
' Map the specified drive to the specified share
' and return True if it mapped, False if it did not.
'************************************************
Function MapDrive(strDrive, strShare)
  On Error Resume Next

  Dim colDrives
  Dim intCnt
  Dim intItem

  'If the directory does not exist
  If Not (fso.FolderExists(strShare)) Then
    MsgBox "Unable to map to " & strShare & " because the directory does not exist! Please notify Help Desk.", vbCritical, "Map Drive Error"
    Exit Function
  End If

  'Get a list of the network drives
  Set colDrives = net.EnumNetworkDrives

  'Get a count of the number of drives (minus one because our loop
  'starts at zero, instead of 1)
  intCnt = colDrives.Count - 1

  'If any drives networked
  If intCnt > 0 Then
    'If the drive matches the drive we want to map, and
    'the share of that drive matches the share we want to map
    'it return's True (already connected). Otherwise,
    'force a disconnect of the currently mapped drive
    '(because it is the incorrect one)
    For intItem = 0 To intCnt Step 2
      If colDrives(intItem) = strDrive Then
        If LCase(colDrives(intItem + 1)) = strShare Then
          MapDrive = True
          Exit Function
        Else
          net.RemoveNetworkDrive strDrive, True, True
        End If
        Exit For
      End If
    Next
  End If
  'Clear any errors that occurred
  Err.Clear

  'Map the drive to the share
  net.MapNetworkDrive strDrive, strShare
  'Return success
  MapDrive = (Err = 0)
  Err.Clear
End Function

'************************************************
' Create a specified folder.
'************************************************
Function CreateFolder(strFolder)
  On Error Resume Next

  With fso
    'If the folder doesn't exist
    If Not .FolderExists(strFolder) Then
      'Log the create folder event
      shell.LogEvent 4, "Attempted to create '" & strFolder & "' folder..."
      'Create the folder
      .CreateFolder strFolder
      'If an error occurred
      If Err Then
       'Log the create folder error
        shell.LogEvent 1, "'" & Err.Description & "' occurred while trying to create the '" & strFolder & "' folder."
      End If
    End If
    'Return True or False (folder exists or not)
    CreateFolder = .FolderExists(strFolder)
  End With
  Err.Clear
End Function

'************************************************
' Main code
'************************************************
On Error Resume Next

'Global variables used throughout all functions
Dim shell, net, fso
Dim strUsername
Dim strOS, strSystemPath, strWinDirPath, strTempPath, strTmpPath, strPRFFolder
Dim blnDriveH, blnDriveL, blnDriveS
Dim sngWaitTime
Dim strSource, strDestination, strServerName

'Pause for 3 second to wait for system to load
sngWaitTime = Timer() + 3
Do
Loop While Timer() < sngWaitTime

'Create references to system objects (ddls)
Set fso = CreateObject("Scripting.FileSystemObject")
Set net = CreateObject("WScript.Network")
Set shell = CreateObject("WScript.Shell")

'Create references to system paths
With shell
   strOS = .ExpandEnvironmentStrings("%OS%")
   strWinDirPath = .ExpandEnvironmentStrings("%WINDIR%")
   strTempPath = .ExpandEnvironmentStrings("%TEMP%")
   strTmpPath = .ExpandEnvironmentStrings("%TMP%")
   Err.Clear

   If strOS = "Windows_NT" Then
      strSystemPath = strWinDirPath & "\System32"
   Else
      strSystemPath = strWinDirPath & "\System"
   End If
End With

'Get the current username
strUsername = CurrentUser()

'If no username was returned
If Len(strUsername) = 0 Then
   shell.Popup "The Logon Script failed to obtain a username and" & vbNewLine & "it therefore cannot continue. Your system may not" & vbNewLine & "be properly configured!", 10, "Logon Script Error"
   WScript.Quit
End If

'Replace <servername> with the name your server here
strServerName = "\\<servername>\"

'Map standard drive letters to specified locations
blnDriveH = MapDrive("H:", strServerName & strUsername & "$")
'Replace <sub_folder_name> with the name of a subfolder on your server
blnDriveL = MapDrive("L:", strServerName & "<sub_folder_name>")
Err.Clear

'If the "home" folder exists, insure the user has these minimum folders in it
If blnDriveH Then
   CreateFolder "H:\My CAD"
   CreateFolder "H:\My Documents"
   CreateFolder "H:\Favorites"
   CreateFolder "H:\Outlook"
   'UpdateOutlook
Else
   MsgBox "Unable to map to your 'Home' directory!", vbCritical
End If

Err.Clear

'Release object variables from memory
Set fso = Nothing
Set net = Nothing
Set shell = Nothing
